{% macro image(img, size) -%}

##### {{ img['file_name'] }}

{{ img['file_size'] | filesizeformat }}
{{ img['image_size'] }}
{{ img['capture_time'] }}
{%- endmacro %} {% macro pagination(current, total) -%}
{%- endmacro %}
{% for dup in duplicates %}
{% set names = dup['items'] %} {% if names | count == 2 %} {{ image(names[0], 6) }} {{ image(names[1], 6) }} {% elif names | count == 3 %} {{ image(names[0], 4) }} {{ image(names[1], 4) }} {{ image(names[2], 4) }} {% elif names | count == 4 %} {{ image(names[0], 3) }} {{ image(names[1], 3) }} {{ image(names[2], 3) }} {{ image(names[3], 3) }} {% elif names | count == 5 %} {{ image(names[0], 2) }} {{ image(names[1], 2) }} {{ image(names[2], 2) }} {{ image(names[3], 2) }} {{ image(names[4], 2) }} {% elif names | count == 6 %} {{ image(names[0], 2) }} {{ image(names[1], 2) }} {{ image(names[2], 2) }} {{ image(names[3], 2) }} {{ image(names[4], 2) }} {{ image(names[5], 2) }} {% elif names | count > 6 %} {% for n in names %} {{ image(n, 1) }} {% endfor %} {% endif %}
{% endfor %} {{ pagination(current, total) }}
Error! File could not be found.